@@ -29,19 +29,19 @@ public:
  */
 void MonthItemOrderTest::longerInstancesFirst()
 {
-    QDate startDate(2000, 01, 01);
-    IncidenceMonthItem *longEvent = eventItem(startDate, startDate.addDays(1));
-    auto longHoliday = new HolidayMonthItem(nullptr, startDate, startDate.addDays(1), QStringLiteral(""));
+    const QDate startDate(2000, 01, 01);
+    const IncidenceMonthItem *longEvent = eventItem(startDate, startDate.addDays(1));
+    auto longHoliday = new HolidayMonthItem(nullptr, startDate, startDate.addDays(1), QString());
     for (int offset = -1; offset < 3; offset++) {
-        QDate d = startDate.addDays(offset);
+        const QDate d = startDate.addDays(offset);
 
-        IncidenceMonthItem *shortEvent = eventItem(d, d);
+        const IncidenceMonthItem *shortEvent = eventItem(d, d);
         QVERIFY(MonthItem::greaterThan(longEvent, shortEvent));
         QVERIFY(!MonthItem::greaterThan(shortEvent, longEvent));
         QVERIFY(MonthItem::greaterThan(longHoliday, shortEvent));
         QVERIFY(!MonthItem::greaterThan(shortEvent, longHoliday));
 
-        auto shortHoliday = new HolidayMonthItem(nullptr, d, QStringLiteral(""));
+        auto shortHoliday = new HolidayMonthItem(nullptr, d, QString());
         QVERIFY(MonthItem::greaterThan(longEvent, shortHoliday));
         QVERIFY(!MonthItem::greaterThan(shortHoliday, longEvent));
         QVERIFY(MonthItem::greaterThan(longHoliday, shortHoliday));
@@ -54,9 +54,9 @@ void MonthItemOrderTest::longerInstancesFirst()
  */
 void MonthItemOrderTest::holidaysFirst()
 {
-    QDate startDate(2000, 01, 01);
-    IncidenceMonthItem *event = eventItem(startDate, startDate);
-    auto holiday = new HolidayMonthItem(nullptr, startDate, QStringLiteral(""));
+    const QDate startDate(2000, 01, 01);
+    const IncidenceMonthItem *event = eventItem(startDate, startDate);
+    auto holiday = new HolidayMonthItem(nullptr, startDate, QString());
     QVERIFY(!MonthItem::greaterThan(event, holiday));
     QVERIFY(MonthItem::greaterThan(holiday, event));
 }
@@ -67,14 +67,14 @@ void MonthItemOrderTest::holidaysFirst()
  */
 void MonthItemOrderTest::stableOrder()
 {
-    QDate startDate(2000, 01, 01);
+    const QDate startDate(2000, 01, 01);
 
-    auto holiday = new HolidayMonthItem(nullptr, startDate, QStringLiteral(""));
-    auto otherHoliday = new HolidayMonthItem(nullptr, startDate, QStringLiteral(""));
+    auto holiday = new HolidayMonthItem(nullptr, startDate, QString());
+    auto otherHoliday = new HolidayMonthItem(nullptr, startDate, QString());
     QVERIFY(!(MonthItem::greaterThan(otherHoliday, holiday) && MonthItem::greaterThan(holiday, otherHoliday)));
 
-    IncidenceMonthItem *event = eventItem(startDate, startDate);
-    IncidenceMonthItem *otherEvent = eventItem(startDate, startDate);
+    const IncidenceMonthItem *event = eventItem(startDate, startDate);
+    const IncidenceMonthItem *otherEvent = eventItem(startDate, startDate);
     QVERIFY(!(MonthItem::greaterThan(otherEvent, event) && MonthItem::greaterThan(event, otherEvent)));
 }
 
